# Generated by Django 5.1 on 2025-05-27 23:00

import post_office.models
import post_office.settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('post_office', '0011_models_help_text'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attachment',
            name='file',
            field=models.FileField(
                storage=post_office.settings.get_file_storage,
                upload_to=post_office.models.get_upload_path,
                verbose_name='File',
            ),
        ),
    ]
